'use strict';
/* eslint-disable no-await-in-loop */
import * as promises from 'node:fs/promises';
import * as path from 'node:path';
import { getPackageDirectories } from './getPackageDirectories.js';
export async function validateClassPaths(unvalidatedClasses, dxConfigFile) {
    const packageDirectories = await getPackageDirectories(dxConfigFile);
    const warnings = [];
    const validatedClasses = new Set();
    for (const unvalidatedClass of unvalidatedClasses) {
        let validated = false;
        for (const directory of packageDirectories) {
            const relativeFilePath = await searchRecursively(`${unvalidatedClass}.cls`, directory);
            if (relativeFilePath !== undefined) {
                validatedClasses.add(unvalidatedClass);
                validated = true;
                break;
            }
        }
        if (!validated)
            warnings.push(`The class ${unvalidatedClass} was not found in any package directory and will not be added to the delta test classes.`);
    }
    return { validatedClasses, warnings };
}
async function searchRecursively(fileName, dxDirectory) {
    const files = await promises.readdir(dxDirectory);
    for (const file of files) {
        const filePath = path.join(dxDirectory, file);
        const stats = await promises.stat(filePath);
        if (stats.isDirectory()) {
            const result = await searchRecursively(fileName, filePath);
            if (result) {
                return result;
            }
        }
        else if (file === fileName) {
            return filePath;
        }
    }
    return undefined;
}
//# sourceMappingURL=validateClassPaths.js.map